@@ -50,6 +50,7 @@ class ExportBlocksJob(BaseJob):
         self.theta_provider = theta_provider
 
         self.batch_work_executor = BatchWorkExecutor(batch_size, max_workers)
+        self.batch_size = batch_size
         self.item_exporter = item_exporter
 
         self.export_blocks = export_blocks
@@ -74,7 +75,8 @@ class ExportBlocksJob(BaseJob):
 
     def _export_batch(self, start_block_height, end_block_height):
         while end_block_height >= start_block_height:
-            tmpE = min(start_block_height + 100, end_block_height)
+            tmpE = min(start_block_height + 99, end_block_height)
+            # tmpE = min(start_block_height + self.batch_size, end_block_height)
             blocks_rpc = generate_get_blocks_by_range_json_rpc(start_block_height, tmpE, self.export_transactions)
             response = self.theta_provider.make_request(json.dumps(blocks_rpc))
             results = rpc_response_to_result(response)
